"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const globals_1 = require("@jest/globals");
const os_1 = __importDefault(require("os"));
const path_1 = __importDefault(require("path"));
const fs_1 = __importDefault(require("fs"));
const got = __importStar(require("got"));
const nodemailer_1 = __importDefault(require("nodemailer"));
const html_1 = __importDefault(require("@leafac/html"));
const _1 = __importDefault(require("."));
globals_1.jest.setTimeout(300000);
globals_1.test("Kill the Newsletter!", async () => {
    // Start servers
    const rootDirectory = fs_1.default.mkdtempSync(path_1.default.join(os_1.default.tmpdir(), "kill-the-newsletter--test--"));
    const { webApplication, emailApplication } = _1.default(rootDirectory);
    const webServer = webApplication.listen(new URL(webApplication.get("url")).port);
    const emailServer = emailApplication.listen(new URL(webApplication.get("email")).port);
    const webClient = got.default.extend({
        prefixUrl: webApplication.get("url"),
    });
    const emailClient = nodemailer_1.default.createTransport(webApplication.get("email"));
    const emailHostname = new URL(webApplication.get("url")).hostname;
    // Create feed
    const create = (await webClient.post("", { form: { name: "A newsletter" } }))
        .body;
    globals_1.expect(create).toMatch(`“A newsletter” inbox created`);
    const feedReference = create.match(/\/feeds\/([a-z0-9]{16})\.xml/)[1];
    // Test feed properties
    const feedOriginal = await webClient.get(`feeds/${feedReference}.xml`);
    globals_1.expect(feedOriginal.headers["content-type"]).toMatch("application/atom+xml");
    globals_1.expect(feedOriginal.headers["x-robots-tag"]).toBe("noindex");
    globals_1.expect(feedOriginal.body).toMatch(html_1.default `<title>A newsletter</title>`);
    // Test alternate
    const alternateReference = feedOriginal.body.match(/\/alternates\/([a-z0-9]{16})\.html/)[1];
    const alternate = await webClient.get(`alternates/${alternateReference}.html`);
    globals_1.expect(alternate.headers["content-type"]).toMatch("text/html");
    globals_1.expect(alternate.headers["x-robots-tag"]).toBe("noindex");
    globals_1.expect(alternate.body).toMatch(`Enjoy your readings!`);
    // Test email with HTML
    await new Promise((resolve) => setTimeout(resolve, 1000)); // Wait for a second to test that the ‘<updated>’ field will be updated
    await emailClient.sendMail({
        from: "publisher@example.com",
        to: `${feedReference}@${emailHostname}`,
        subject: "Test email with HTML",
        html: html_1.default `<p>Some HTML</p>`,
    });
    const feedWithHTMLEntry = (await webClient.get(`feeds/${feedReference}.xml`))
        .body;
    globals_1.expect(feedWithHTMLEntry.match(/<updated>(.+?)<\/updated>/)[1]).not.toBe(feedOriginal.body.match(/<updated>(.+?)<\/updated>/)[1]);
    globals_1.expect(feedWithHTMLEntry).toMatch(html_1.default `<author><name>publisher@example.com</name></author>`);
    globals_1.expect(feedWithHTMLEntry).toMatch(html_1.default `<title>Test email with HTML</title>`);
    globals_1.expect(feedWithHTMLEntry).toMatch(
    // prettier-ignore
    html_1.default `<content type="html">${`<p>Some HTML</p>`}\n</content>`);
    // Test email with text
    await emailClient.sendMail({
        from: "publisher@example.com",
        to: `${feedReference}@${emailHostname}`,
        subject: "Test email with text",
        text: "A link: https://kill-the-newsletter.com",
    });
    globals_1.expect((await webClient.get(`feeds/${feedReference}.xml`)).body).toMatch(
    // prettier-ignore
    html_1.default `<content type="html">${`<p>A link: <a href="https://kill-the-newsletter.com">https://kill-the-newsletter.com</a></p>`}</content>`);
    // Test email missing fields
    await emailClient.sendMail({
        to: `${feedReference}@${emailHostname}`,
    });
    const feedMissingFields = (await webClient.get(`feeds/${feedReference}.xml`))
        .body;
    globals_1.expect(feedMissingFields).toMatch(html_1.default `<author><name></name></author>`);
    globals_1.expect(feedMissingFields).toMatch(html_1.default `<title></title>`);
    globals_1.expect(feedMissingFields).toMatch(html_1.default `<content type="html"></content>`);
    // Test email to nonexistent ‘to’ (gets ignored)
    await emailClient.sendMail({
        from: "publisher@example.com",
        to: `nonexistent@${emailHostname}`,
        subject: "Test email to nonexistent ‘to’ (gets ignored)",
        text: "A link: https://kill-the-newsletter.com",
    });
    globals_1.expect((await webClient.get(`feeds/${feedReference}.xml`)).body).not.toMatch("Test email to nonexistent ‘to’ (gets ignored)");
    // Test truncation
    for (let index = 1; index <= 5; index++)
        await emailClient.sendMail({
            from: "publisher@example.com",
            to: `${feedReference}@${emailHostname}`,
            subject: `Test truncation: ${index}`,
            text: `TRUNCATION ${index} `.repeat(10000),
        });
    const feedTruncated = (await webClient.get(`feeds/${feedReference}.xml`))
        .body;
    globals_1.expect(feedTruncated).toMatch("TRUNCATION 5");
    globals_1.expect(feedTruncated).not.toMatch("TRUNCATION 1");
    // Test email that’s too long
    await emailClient.sendMail({
        from: "publisher@example.com",
        to: `${feedReference}@${emailHostname}`,
        subject: "Test email that’s too long",
        text: `TOO LONG `.repeat(100000),
    });
    const feedEvenMoreTruncated = (await webClient.get(`feeds/${feedReference}.xml`)).body;
    globals_1.expect(feedEvenMoreTruncated).not.toMatch("TOO LONG");
    globals_1.expect(feedEvenMoreTruncated).not.toMatch("TRUNCATION 5");
    // Test email after truncation
    await emailClient.sendMail({
        from: "publisher@example.com",
        to: `${feedReference}@${emailHostname}`,
        subject: "Test email after truncation",
        text: "A link: https://kill-the-newsletter.com",
    });
    globals_1.expect((await webClient.get(`feeds/${feedReference}.xml`)).body).toMatch(
    // prettier-ignore
    html_1.default `<title>Test email after truncation</title>`);
    // Stop servers
    webServer.close();
    emailServer.close();
});
//# sourceMappingURL=index.test.js.map